import { Datasource, IEventParam, IDictionary } from '@zeedhi/core';
import { Button, Grid, GridEditable } from '@zeedhi/common';

export class ParametersDashboardController {
  public departmentName: string = '';
  
  public disabled: boolean = false;

  public showAnotherDetail = false;

  get anotherMasterIsVisible() {
    return !this.showAnotherDetail;
  }

  private async deleteAndUpdate(datasource: Datasource, row: IDictionary<any>) {
    await datasource.delete(row);
    datasource.get();
  }

  public departmentGridCellClick({ row, column, component }: IEventParam<Grid>) {
    const isDeleteAction = column.name === 'delete-action';
    if (isDeleteAction) {
      this.deleteAndUpdate(component.datasource, row);
    }
    return isDeleteAction;
  }

  public departmentGridRowClick({ row }: IEventParam<Grid>) {
    this.showAnotherDetail = true;
    this.departmentName = row.name;
  }

  public showAnotherMaster() {
    this.showAnotherDetail = false;
  }
  
  public testCellIsEditable({ row }: IDictionary<any>) {
    return parseFloat(row.id) % 3 !== 0;
  }

  public isNotInlineEditingConditions = true;

  public onInlineEditConditions({ component }: IEventParam<GridEditable>) {
    this.isNotInlineEditingConditions = !component.editing;
  }

  public async cancelEditingConditions({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    await grid.cancelEditedRows();
    this.onInlineEditConditions({ component: grid });
  }

  public async saveEditingConditions({ component }: IEventParam<Button>) {
    const grid = component.parent as GridEditable;
    await grid.saveEditedRows();
    this.onInlineEditConditions({ component: grid });
  }
}
